<?xml version="1.0"?>

<!-- ******************************************************************** 
* This XSLT script  was generated by the XSLerator                          
*                                                                           
* IBM MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY          
* OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED     
* TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR    
* PURPOSE, OR NON-INFRINGEMENT. IBM SHALL NOT BE LIABLE FOR ANY DAMAGES     
* SUFFERED BY LICENSEE AS A RESULT OF USING OR MODIFYING THIS SOFTWARE      
* OR ITS DERIVATIVES                                                        
*                                                                          
*************************************************************************** -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="java">
<xsl:output method="html" indent="yes"/>
<xsl:output encoding="ISO-8859-1"/>
<xsl:strip-space elements="*"/>

<xsl:template match="data-dictionary">


<!--
* Currently the xsl and data-dictionary files have to be in the same location. As you can see from
* the below line, the path/location is hard-coded! The various options to get this working are:
* 1) If the transformation is done from a Java program, we can use the system-property function to get
* the exact location of the data-dictionary file!
* 2) If run from .bat/.sh we can set a environment variable and access the same using the 
* system-property method!
-->	
    <html>
        <!--
        * The Head contains the Title as Data Model Definition for <moduleName>
        -->
	<xsl:variable name="t2-1.data-dictionary.name" select="@name"/>
	<head>
	
	<xsl:if test="$t2-1.data-dictionary.name!=''">
            <xsl:element name="title">
		<xsl:value-of select="concat('Data Model definition for ',$t2-1.data-dictionary.name)"/>
            </xsl:element>
	</xsl:if>
          <style type="text/css">
            h1 {
              font-size: 120%;
              text-align: center;
            }
            
            h2 {
              font-size: 100%;
              font-weight: bold;
              border-bottom: 1px ridge;
              margin-top: 3em;
              letter-spacing: 2px;
            }

            h3 {
              font-size: 95%;
              font-weight: bold;
              letter-spacing: 4px;
              margin-left: 2em;
            }
            
            p {
              margin-left: 4em;
              font-size: 11 px;       
            }
            
            table {
              background-color: #000000;
              font-size: 11px;
              margin-left: 2em;
            }
            
            th {
                background-color: #82b15f;
                color: #ffffff;
                font-weight: bold;
                font-size: 12px;
                text-align: center;
                vertical-align: middle;
            }

            td {
                background-color: #ddead5;
                color: #000000;
            }

            ul li {
              margin-bottom: 0.5em;
            }
            
            .keyword {
              color:#6b974;
              font-weight: bold;
              
            }

            .tablename {
              font-weight: normal;
              font-size: 11px;
            }
            .bodytext{
              font-size: 11px;
            }

         </style>

	</head>
        
        <!--
        * The body has a page title as Data Model Definition for <moduleName>, same as the document title
        -->
        <body text="#000000" bgcolor="#ffffff" link="#000099" vlink="#990099" alink="#000099" class="bodytext">
        
        <h1>
          <xsl:if test="$t2-1.data-dictionary.name!=''">
            <xsl:value-of select="concat('Data Model definition for ',$t2-1.data-dictionary.name)"/>
          </xsl:if>
        </h1>
    
        <!-- Tables count -->
        <!--center><small>(<xsl:value-of select="count(table)"/> tables)</small></center-->

        
        <!--
         * Any useful description provided for the data-dictionary!
        -->
        <xsl:variable name="t2-2.data-dictionary.description" select="description"/>
	<xsl:if test="$t2-2.data-dictionary.description!=''">
            <xsl:element name="h2">
                <xsl:value-of select="'Description:'"/>
            </xsl:element>
            <xsl:element name="p">
		<xsl:value-of select="$t2-2.data-dictionary.description" disable-output-escaping="yes"/>
            </xsl:element>
        </xsl:if>
        
        <!--
         * Here we go on the list of tables defined in this data-dictionary.
        -->
        <xsl:variable name="t4-5.data-dictionary.table" select="table"/>
        <xsl:for-each select="$t4-5.data-dictionary.table">
            <xsl:variable name="t2-5.data-dictionary.table.name" select="@name"/>
            <!--
             * Start the table definition in a separate para!
            -->
            <h2>
              <xsl:if test="$t2-5.data-dictionary.table.name!=''">
		      <!--
		      <xsl:element name="TableName">
			      -->
                    <xsl:number value="position()" format="1. "/>
					<a>
					<xsl:attribute name="name">
						<xsl:value-of select="$t2-5.data-dictionary.table.name"/>
					</xsl:attribute>
					</a>
					<xsl:value-of select="$t2-5.data-dictionary.table.name"/>
              </xsl:if>
            </h2>
                
                <!--
                  * The description is the next separate para!
                -->
                <xsl:variable name="t2-6.data-dictionary.table.description" select="description"/>
                    <xsl:if test="$t2-6.data-dictionary.table.description!=''">
               <p>
                        <xsl:element name="description">
                            <xsl:value-of select="$t2-6.data-dictionary.table.description" disable-output-escaping="yes"/>
			</xsl:element>
               </p>
                    </xsl:if>
               
               <!--
                * Declare the variables that will be used with in the for-each loop!
               -->
		<xsl:variable name="t2-10.data-dictionary.table.columns.column" select="columns/column"/>
                <xsl:variable name="t2-10.data-dictionary.table.primary-key" select="primary-key"/>
                <xsl:variable name="t2-10.data-dictionary.table.primary-key.primary-key-column" select="primary-key/primary-key-column"/>
                <xsl:variable name="t2-10.data-dictionary.table.foreign-key" select="foreign-keys/foreign-key"/>
		<xsl:variable name="t2-10.data-dictionary.table.unique-key" select="unique-keys/unique-key"/> 
		
                <!--
                * Now we go on to the HTML table building stuff!
                -->
		<table cellpadding="4" cellspacing="1" border="0" width="95%">
                    <tbody>
                        <tr>
                        <!--
                        * The table headers are defined a different style to differentiate from the other
                        * columns.
                        -->
                          <th> Column name             </th>
                          <th> Description             </th>
                          <th> Data type               </th>
                          <th> Max size                </th>
                          <th> Default value           </th>
                          <th> Nullable                </th>
                          <th> Unique                  </th>
                          <th> Allowed values          </th>
                          <th> Unique value generation </th>
                        </tr>
                      
                        <!--
                        * Each column occupies a different Row in this table!
                        * We are adding an empty <br></br> tag here so that the generated
                        * table is more readable!
                        -->  
                      <xsl:for-each select="$t2-10.data-dictionary.table.columns.column">
                        <tr>
			<xsl:variable name="t2-10.data-dictionary.table.columns.column.name" select="@name"/>
			<xsl:variable name="column-name" select="$t2-10.data-dictionary.table.columns.column.name"/>
                	<xsl:element name="td">
                        <xsl:value-of select="$column-name"/>
                        
                        <!--
                        * Find if "this" column is a Primary Key column and mark it appropriately.
                        * TODO: We can also find Foriegn-Key columns and mark it like this. 
                        * Also, its better we define an anchor for this column. This will be useful
                        * for us to "link" to this column from different location etc.,
                        -->
                        <xsl:if test="$t2-10.data-dictionary.table.primary-key!=''">
                            <xsl:for-each select="$t2-10.data-dictionary.table.primary-key.primary-key-column">
			<!--
			* We compare twice to ensure the equality of the compared Strings!
			-->
                                <xsl:if test="contains(current(),$column-name)">
				    <xsl:if test="contains($column-name,current())">
					<a>
					<xsl:attribute name="name">
					<xsl:value-of select="concat($t2-5.data-dictionary.table.name,$column-name)"/>
					</xsl:attribute>
					</a>
					<b>
					<xsl:value-of select="' (PK)'"/>
					</b>
				   </xsl:if>
				 </xsl:if>
                            </xsl:for-each>
                        </xsl:if>
                        <br/>
                        </xsl:element>
                        
    			<xsl:variable name="t2-11.data-dictionary.table.columns.column.description" select="description"/>
			<xsl:element name="td">
                            <xsl:value-of select="$t2-11.data-dictionary.table.columns.column.description" disable-output-escaping="yes"/>
                            <br/>
			</xsl:element>
                        
			<xsl:variable name="t2-13.data-dictionary.table.columns.column.data-type" select="data-type"/>
			<xsl:element name="td">
                            <xsl:value-of select="$t2-13.data-dictionary.table.columns.column.data-type"/>
                            <br/>
			</xsl:element>
                        
			<xsl:variable name="t2-15.data-dictionary.table.columns.column.max-size" select="max-size"/>
                        <xsl:element name="td">
                            <xsl:value-of select="$t2-15.data-dictionary.table.columns.column.max-size"/>
                            <br/>
			</xsl:element>
                        
			<xsl:variable name="t2-17.data-dictionary.table.columns.column.default-value" select="default-value"/>
			<xsl:element name="td">
                            <xsl:value-of select="$t2-17.data-dictionary.table.columns.column.default-value"/>
                            <br/>
			</xsl:element>
                        
                        <xsl:variable name="t2-19.data-dictionary.table.columns.column.nullable" select="nullable"/>
                        <xsl:element name="td">
                            <xsl:value-of select="$t2-19.data-dictionary.table.columns.column.nullable"/>
                            <br/>
			</xsl:element>
                        
                        <xsl:variable name="t2-21.data-dictionary.table.columns.column.unique" select="unique"/>
			<xsl:element name="td">
                            <xsl:value-of select="$t2-21.data-dictionary.table.columns.column.unique"/>
                            <br/>
			</xsl:element>
                        
                        <!--
                        * We have two categories of allowed-values. One is the From-to range and the other is 
                        * the list of values. We are providing options to show these two categories in a distinct
                        * fashion!
                        -->
                        <xsl:variable name="t2-23.data-dictionary.table.columns.column.allowed-values" select="allowed-values"/>
			<xsl:element name="td">
                            <xsl:variable name="t2-23.data-dictionary.table.columns.column.allowed-values.from" select="allowed-values/from"/>
                                <xsl:if test="$t2-23.data-dictionary.table.columns.column.allowed-values.from!=''">
                                    <xsl:value-of select="$t2-23.data-dictionary.table.columns.column.allowed-values.from"/>
				</xsl:if>
                                
                             <xsl:variable name="t2-23.data-dictionary.table.columns.column.allowed-values.to" select="allowed-values/to"/>
                                <xsl:if test="$t2-23.data-dictionary.table.columns.column.allowed-values.to!=''">
                                    <xsl:value-of select="concat(' - ',$t2-23.data-dictionary.table.columns.column.allowed-values.to)"/>
				</xsl:if>
                                
                              <xsl:variable name="t2-23.data-dictionary.table.columns.column.allowed-values.value" select="allowed-values/value"/>
				<xsl:for-each select="$t2-23.data-dictionary.table.columns.column.allowed-values.value">
					<li>
						<xsl:value-of select="current()"/>
					</li>
				</xsl:for-each>
                                <br/>
			</xsl:element>
                        
			<xsl:variable name="t2-28.data-dictionary.table.columns.column.uniquevalue-generation" select="uniquevalue-generation"/>
			<xsl:element name="td">
                            <xsl:value-of select="$t2-28.data-dictionary.table.columns.column.uniquevalue-generation"/>
                            <br/>
			</xsl:element>
		</tr>
		</xsl:for-each>
		</tbody>
			
		</table>
                
    <!--
     * Below the table, we define the other constraints such as Primary Key, Foreign-Key
     * Currently we are not supporting the Unique-Key constraints here because, the
     * data-dictionary will be enhanced in future to support a special unique-key constraint
     * definition tag!
    -->
    <xsl:if test="$t2-10.data-dictionary.table.primary-key!=''">
        <h3>Constraints</h3>
        <!--
        * The Primary Key definition!
        -->
        <ul type="square">
        <li>
        <span class="keyword"><xsl:value-of select="'Primary key '"/></span>
        <span class="tablename"><xsl:value-of select="@name"/></span>
        <xsl:value-of select="'('"/>

        <xsl:for-each select="$t2-10.data-dictionary.table.primary-key.primary-key-column">
            <xsl:if test="not(contains(position(),'1'))">
                 <xsl:value-of select="','"/>
            </xsl:if>
            <xsl:value-of select="current()"/>
        </xsl:for-each>

        <xsl:value-of select="')'"/>
        </li>

            <!--
            * The foreignKey definition. 
            -->
            <xsl:if test="$t2-10.data-dictionary.table.foreign-key!=''">

               <xsl:for-each select="$t2-10.data-dictionary.table.foreign-key">
                  <li>
                  <span class="keyword"><xsl:value-of select="'Foreign key '"/></span>
                  <span class="tablename"><xsl:value-of select="@name"/></span>
                  <xsl:value-of select="'('"/>
                  <xsl:variable name="t2-10.data-dictionary.table.foreign-key.fk-column" select="fk-columns/fk-column"/>
                        
                  <xsl:for-each select="$t2-10.data-dictionary.table.foreign-key.fk-column">
                    <xsl:if test="not(contains(position(),'1'))">
                        <xsl:value-of select="', '"/>
                    </xsl:if>
                    <xsl:value-of select="fk-local-column"/>
                  </xsl:for-each>
                        
                  <xsl:value-of select="')'"/>
                  <span class="keyword"><xsl:value-of select="' references '"/></span>    
                  <span class="tablename">
				  <a>
				  <xsl:attribute name="href">
                                  <xsl:text>ddTableTransformer.do?tableNames=</xsl:text>
				  <xsl:value-of select="@reference-table-name"/>
                                  </xsl:attribute>
				  <xsl:value-of select="@reference-table-name"/>
				  </a>
				  </span>
				  <xsl:variable name="table-name">
				  	<xsl:value-of select="@reference-table-name"/>
				  </xsl:variable>
                  <xsl:value-of select="'('"/>

					
                  <xsl:for-each select="$t2-10.data-dictionary.table.foreign-key.fk-column">
                    <xsl:if test="not(contains(position(),'1'))">
                      <xsl:value-of select="', '"/>
                    </xsl:if>
					<a>
					<xsl:attribute name="href">
                                        <xsl:text>ddTableTransformer.do?tableNames=</xsl:text>

					<xsl:value-of select="concat($table-name,'#',fk-reference-column)"/>
					</xsl:attribute>
					<xsl:value-of select="fk-reference-column"/>
					</a>
                  </xsl:for-each>
                              
                  <xsl:value-of select="') '"/>
                  <span class="keyword"><xsl:value-of select="fk-constraints"/></span>

                  <xsl:if test="contains(@isbidirectional,'true')">
                    <xsl:value-of select="' and '"/>
                    <span class="keyword"><xsl:value-of select="'bidirectional'"/></span>
                  </xsl:if>
                  </li>
               </xsl:for-each>

            </xsl:if>

	<!--
	* Unique Key definitions
	-->
	<xsl:if test="$t2-10.data-dictionary.table.unique-key!=''">

		<xsl:for-each select="$t2-10.data-dictionary.table.unique-key">
			<li>
				<span class="keyword"><xsl:value-of select="'Unique '"/></span>
				<span class="tablename"><xsl:value-of select="@name"/></span>
				<xsl:value-of select="'('"/>
				<xsl:variable name="t2-10.data-dictionary.table.unique-key.unique-key-column" select="unique-key-column"/>

				<xsl:for-each select="$t2-10.data-dictionary.table.unique-key.unique-key-column">
					<xsl:if test="not(contains(position(),'1'))">
						<xsl:value-of select="', '"/>
					</xsl:if>
					<xsl:value-of select="current()"/>
				</xsl:for-each>

				<xsl:value-of select="')'"/>
			</li>
		</xsl:for-each>
	</xsl:if>
	</ul>
	</xsl:if>
    </xsl:for-each>
    
    </body>
   </html>
   
  </xsl:template>
</xsl:stylesheet>
