//$Id: PropertySheetLayout.js,v 1.1 2005/04/29 09:27:00 shanmugampl Exp $

/**
 * Contains the JS dataobject reference.
 */
var _viewDataObject = new Array();

/**
 * Contains the columnalias values in the order thay are to be displayed. This
 * list will be constructed from the ACPSConfiguration if present, else from
 * TmpViewColumns. Any change in the order of display will be updated here and
 * then to the javascript dataobject. Also this list will contain only the
 * ColumnAlias values(i.e either the key/value). The other value will be added
 * at runtime.
 */
var _viewNames = new Array();

/**
 * Contains the columnalias values in their original order.
 */
var _originalViewNames = new Array();

/**
 * Specifies the id at which the generated table is to be inserted.
 */
var _insId = null;

/**
 * Specifies the type of table construction. It can have any one of the two
 * values namely 'SingleColumn' & 'DoubleColumn'.
 */
var _layoutType = 'SingleColumn';

/**
 * Contains the config name of the ACPSConfiguration table. 
 */
var _configName = "";

/**
 * Initializes the LayoutArea for the PropertySheet with the provided
 * dataObject and of the layout type specified.
 */
function initPSLayout(dataObject, insertionId, type){
	_layoutType = type;
	_viewDataObject = dataObject;
	var viewDetails = _viewDataObject.getRowsForTable("TmpViewDetails");
	// Set the componentName and the psconfiglist values for the
	// ACTableViewConfig in TmpViewDetails.
	viewDetails[0][COMPONENTNAME] = "ACPSTable";
	viewDetails[0]["PSCONFIG"] = _configName;
	_configName = viewDetails[0][VIEWNAME];
	var validViewCount = 0;

	if(!_viewDataObject.containsTable('ACPSConfiguration')){
		var tablerows = _viewDataObject.getRowsForTable("TmpViewColumn");
		for(var index in tablerows){
			var colAl = tablerows[index][COLUMNALIAS];
			// Only the columns  whose visility is set to true can be layed out.
			// Therefore add only those.
			if(tablerows[index][VISIBLE]== "true"){
				addPSConfigTable(validViewCount,"0","Label",tablerows[index][DISPLAYNAME]);
				addPSConfigTable(validViewCount,"1","FieldValue",colAl);
				validViewCount++;
			}
		}		
	}

	// Extract the viewNames from the ACPSConfiguration table. Names whose
	// DATATYPE is set to  FieldValue should alone be taken since we are going to
	// display only the key.
	validViewCount = 0;
	var psConfigRows = _viewDataObject.getRowsForTable("ACPSConfiguration");
	for(var index in psConfigRows){
		if(psConfigRows[index]["DATATYPE"] == "FieldValue"){
			_viewNames[validViewCount] = psConfigRows[index]["DATAVALUE"];
			_originalViewNames[validViewCount] = psConfigRows[index]["DATAVALUE"];
			validViewCount++;
		}
	}
	_insId = insertionId;
	showGrid(constructLayout());
}

/**
 * Reconstructs the dataObject for ACPSConfiguration with the updates order and
 * calls the required construction method.
 */
function constructLayout() {
	_viewDataObject.deleteAllRowsInTable("ACPSConfiguration","CONFIGNAME",_configName);
	for(var name in _viewNames){
		var rowObj = _viewDataObject.getFirstRow("TmpViewColumn",COLUMNALIAS,_viewNames[name]);
		addPSConfigTable(name,"0","Label",rowObj[DISPLAYNAME]);
		addPSConfigTable(name,"1","FieldValue",rowObj[COLUMNALIAS]);
	}
//	document.getElementById("Testing").innerHTML = _viewDataObject.displayDO();
	if(_layoutType == 'SingleColumn'){
		return constructSingleColumnGrid();
	}
	draggedViewName = null;
}

function constructSingleColumnGrid() {
	var grid = "<TABLE id='editTable' cellspacing='2' align='center' border='0'>";
	var size = _viewNames.length;
	for(var count = 0; count < size; count++){
		var html = document.getElementById("GridView").innerHTML;
		var rowObject = _viewDataObject.getFirstRow("TmpViewColumn",COLUMNALIAS,_viewNames[count]);
		var colRow = _viewDataObject.getFirstRow("ACPSConfiguration",COLUMNALIAS,_viewNames[count]);
		var newHtml = html.replace(/\$ID/g, count);
		newHtml = newHtml.replace('$VN', "");
		newHtml = newHtml.replace('$DISPLAYNAME', rowObject[DISPLAYNAME]);
		newHtml = newHtml.replace(/\$TITLE/g, rowObject[COLUMNALIAS]);
		grid = grid.concat("<TR><TD ");
		if(draggedViewName != null && draggedViewName == colRow[COLUMNALIAS]){
			grid = grid.concat(" class='lastDragged'")
		}
		grid = grid.concat(" id='_evInd' onMouseOver='enableViewSelection(document.getElementById(\"_ev" + count + "\"))'>"+newHtml+"</TD></TR>");
	}
	grid = grid.concat("</TR></TABLE>");
	return grid;
}

var currentGrid = null;
var draggedViewName = null;

/**
 *
 */
function showGrid(grid){
	currentGrid = grid;
	setTimeout("dummy()",1);
}

function dummy(){
	document.getElementById(_insId).parentNode.parentNode.parentNode.innerHTML = "<table style='border:1px #FF0000' cellpadding='0' cellspacing='1' bgcolor='#CBC0AB'><tr id='previewTableContainerRow' class='tableHeader'><td>" + currentGrid + "</td></tr></table>";
}

function insertView(draggedViewObj, insertId){
	 draggedViewName  = draggedViewObj.getAttribute("viewName");
	var draggedViewTitle  = draggedViewObj.getAttribute("title");
	var viewObject = new Array(draggedViewName, draggedViewTitle);
	var insertBefore = document.getElementById(insertId).getAttribute('viewId');
	var valid = false;
	if(insertId.indexOf('_ev') >= 0){
		if(insertBefore >= 0){
			_viewNames.splice(insertBefore, 0, viewObject);	
			valid = true;
		}
		else {
			_viewNames[_viewNames.length] = viewObject;
			valid = true;
		}
	}
	if(valid) {
		showGrid(constructLayout());
	}
	return valid;
}

function changeView(htmlObject, insertId){
	var insertBefore = document.getElementById(insertId).getAttribute('viewId');
	var currentId = htmlObject.getAttribute('viewId');
	draggedViewName  = htmlObject.getAttribute("viewName");
	var viewObject = _viewNames[currentId];
	var valid = false;
	if(insertId.indexOf('_ev') >= 0){
		if(insertBefore >= 0){
			if(insertBefore < currentId){
				_viewNames.splice(currentId, 1);	
				_viewNames.splice(insertBefore, 0, viewObject);	
			}
			else {
				_viewNames.splice(insertBefore, 0, viewObject);	
				_viewNames.splice(currentId, 1);	
			}
			valid = true;
		}
		else {
				_viewNames.splice(currentId, 1);	
				_viewNames[_viewNames.length] = viewObject;
				valid = true;
		}
	}
	if(valid) {
	showGrid(constructLayout());
	}
	return valid;
}

function resetGrid(){
	_viewNames = new Array();
	for(var i = 0; i < _originalViewNames.length; i++){
		_viewNames[i] = _originalViewNames[i];
	}
	showGrid(constructLayout());
}

/**
 * Creates and adds an ACPSConfiguration row to the dataobject.
 */
function addPSConfigTable(rowIndex, columnIndex, dataType, dataValue){
	_viewDataObject.addRowsForTable("ACPSConfiguration",
																	new Array(new Array("CONFIGNAME", _configName),
																						new Array("ROWINDEX",rowIndex),
																						new Array("COLUMNINDEX",columnIndex),
																						new Array("DATATYPE",dataType),
																						new Array("DATAVALUE",dataValue)
																	));
}
